@@ -1,5 +1,5 @@
 #!/bin/sh
-# @(#) $Id: updatetimestamps.sh 316 2022-07-15 22:57:40Z leres $ (XSE)
+# @(#) $Id: updatetimestamps.sh 320 2022-12-12 23:21:34Z leres $ (XSE)
 #
 # updatetimestamps - image the timestamps section of a webindex.conf file
 #
@@ -34,7 +34,7 @@ gentimestamps()
 	ls ${d} | awk '
 	BEGIN {
 	}
-	/\.(jpg|JPG|png|PNG|gif|GIF|mov|MOV|mpg|mp4|MPG|tif|TIF)$/ {
+	/\.(jpg|JPG|png|PNG|gif|GIF|mov|MOV|mp3|mpg|mp4|MPG|tif|TIF)$/ {
 		if ($0 ~ /"/) {
 			# Silently skip
 			next
